aboutsummaryrefslogtreecommitdiff
path: root/widgets/hddtemp.lua
diff options
context:
space:
mode:
Diffstat (limited to 'widgets/hddtemp.lua')
-rw-r--r--widgets/hddtemp.lua8
1 files changed, 4 insertions, 4 deletions
diff --git a/widgets/hddtemp.lua b/widgets/hddtemp.lua
index 6fcd05f..e5ab96d 100644
--- a/widgets/hddtemp.lua
+++ b/widgets/hddtemp.lua
@@ -16,12 +16,12 @@ module("vicious.widgets.hddtemp")
-- {{{ HDD Temperature widget type
-local function worker(format, port)
- -- Fallback to default hddtemp port
- if port == nil then port = 7634 end
+local function worker(format, warg)
+ -- Fallback to default hddtemp warg
+ if warg == nil then warg = 7634 end
-- Get info from the hddtemp daemon
- local f = io.popen("curl --connect-timeout 1 -fsm 3 telnet://127.0.0.1:"..port)
+ local f = io.popen("curl --connect-timeout 1 -fsm 3 telnet://127.0.0.1:"..warg)
local hdd_temp = {}
for line in f:lines() do